MENU = "Menu"

IOHJV = "Isle O Hags - Jinjo Village"
IOHJVKP  = "Isle O Hags - King Jingaling Palace"
IOHJVGJ  = "Isle O Hags - Green Jinjo House"
IOHJVBLKJ  = "Isle O Hags - Black Jinjo House"
IOHJVYJ  = "Isle O Hags - Yellow Jinjo House"
IOHJVBLUJ  = "Isle O Hags - Blue Jinjo House"
IOHJVBWNJ  = "Isle O Hags - Brown Jinjo House"
IOHJVOJ  = "Isle O Hags - Orange Jinjo House"
IOHJVPJ  = "Isle O Hags - Purple Jinjo House"
IOHJVRJ  = "Isle O Hags - Red Jinjo House"
IOHJVWJ  = "Isle O Hags - White Jinjo House"

IOHWH  = "Isle O Hags - Wooded Hollow"
IOHWL  = "Isle O Hags - Wasteland"
IOHQM  = "Isle O Hags - Quagmire"
IOHHB  = "Isle O Hags - Honey B's Hive"
IOHPL  = "Isle O Hags - Plateau"
IOHWW  = "Isle O Hags - Wumba's Wigwam"
IOHPG  = "Isle O Hags - Pine Grove"
IOHPGU  = "Isle O Hags - Pine Grove Underwater"
IOHJT  = "Isle O Hags - Jiggywiggy Temple"
IOHCT  = "Isle O Hags - Cliff Top"
IOHCTS = "Isle O Hags - Cliff Top Station"
IOHCT_HFP_ENTRANCE = "Isle O Hags - Cliff Top (Across Bridge)"
IOHDC  = "Isle O Hags - Another Digger Tunnel"

# These are the loading zones to each level, as seen from OUTSIDE the level. For example, MTE is the loading zone in Wooded Hollow, that normally leads to MT.
MTE = "Mayahem Temple - Main Entrance"
GGME = "Glitter Gulch Mine - Main Entrance"
WWE = "Witchyworld - Main Entrance"
JRLE = "Jolly Roger's Lagoon - Main Entrance"
TDLE = "Terrydactyland - Main Entrance"
GIE = "Grunty Industries - Main Entrance"
HFPE = "Hailfire Peaks - Main Entrance"
CCLE = "Cloud Cuckooland - Main Entrance"
CKE = "Cauldron Keep - Main Entrance"

SMBH = "Spiral Mountain - Banjo's House"
SMGL = "Spiral Mountain - Gruntilda's Lair"
SMBW = "Spiral Mountain - Behind Waterfall"
SM   = "Spiral Mountain"
SMDT = "Sprial Mountain - Digger Tunnel"

MT = "Mayahem Temple"
MTCDC = "Mayahem Temple - Code Chamber"
MTCC = "Mayahem Temple - Column Chamber"
MTTT = "Mayahem Temple - Targitzan's Temple"
MTJSG = "Mayahem Temple - Jade Snake Grove"
MTPC = "Mayahem Temple - Prison Compound"
MTKS = "Mayahem Temple - Kickball Stadium"

GM = "Glitter Gulch Mine"
GMS = "Glitter Gulch Mine Station"
GMWSJT = "Glitter Gulch Mine - Water Storage Jinjo Tank"
GMFD = "Glitter Gulch Mine - Fuel Depot, Behind the Rocks"

WW = "Witchyworld"
WWS = "Witchyworld Station"
WWI = "Witchyworld - The Inferno"
WWA51NESTS = "Witchyworld - Area 51 Egg Nests"

JR = "Jolly Roger's Lagoon - Town Center"
JRU = "Jolly Roger's Lagoon - Underwater At Start"
JRAT = "Jolly Roger's Lagoon - Atlantis"
JRSS = "Jolly Roger's Lagoon - Sunken Ship"
JRLC = "Jolly Roger's Lagoon - Locker Cavern"
JRBFC = "Jolly Roger's Lagoon - Big Fish Cavern"
JRSS2 = "Jolly Roger's Lagoon - Seaweed Sanctum"

TL = "Terrydactyland"
TLS = "Terrydactyland Station"
TL_HATCH = "Terrydactyland - Hatch Cave"
TLSP = "Terrydactyland - Stomping Plains"
TLTOP = "Terrydactyland - Top of the Mountain"
TLIMTOP = "Terrydactyland - Inside the Mountain, Top"

GIO = "Outside Grunty Industries"
GIOB = "Outside Grunty Industries - Behind the building"
GIES = "Grunty Industries Elevator Shaft"
GI1 = "Grunty Industries 1st Floor"
GI2 = "Grunty Industries 2nd Floor"
GI2EM = "Grunty Industries 2nd Floor - Eletromagnetic Chamber"
GI3 = "Grunty Industries 3rd Floor"
GI3B = "Grunty Industries 3rd Floor - Boiler Plant"
GI4 = "Grunty Industries 4th Floor"
GI4B = "Grunty Industries 4th Floor - Past the Crushers"
GIR = "Grunty Industries Roof"
GI5 = "Grunty Industries Floor 5"
GIS = "Grunty Industries Station"
GIF = "Grunty Industries - Flight"

HP = "Hailfire Peaks"
HPIS = "Hailfire Peaks Icy Station"
HPLS = "Hailfire Peaks Lava Station"
CC = "Cloud Cuckooland"
CK = "Cauldron Keep"
H1 = "HAG 1"
CHUFFY = "Chuffy's Cabin"

# These regions represent the act of using warps between different sections of a world.
IHSILOS = "Isle O' Hag Silos"
MTWARP = "Mayahem Temple Warp Pads"
GMWARP = "Glitter Gulch Mine Warp Pads"
WWWARP = "Witchyworld Warp Pads"
JRWARP = "Jolly Roger Lagoon Warp Pads"
TLWARP = "Terrydactyland Warp Pads"
GIWARP = "Grunty Industries Warp Pads"
HPWARP = "Hailfire Peaks Warp Pads"
CCWARP = "Cloud Cuckooland Warp Pads"
CKWARP = "Cauldron Keep Warp Pads"

# Bosses needed for Rando. Don't change these names
MTBOSS  = "Targitzan's Really Sacred Chamber"
GMBOSS  = "Inside Chuffy's Boiler"
WWBOSS  = "Big Top Interior"
JRBOSS  = "Davy Jones' Locker"
TLBOSS  = "Terry's Nest"
GIBOSS  = "Repair Depot"
HPFBOSS = "Chilli Billi Crater"
HPIBOSS = "Chilly Willy Crater"
CCBOSS  = "Mingy Jongo Skull"
